exceptiontools.TupletFuseError
==============================

.. abjad-lineage:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError

.. autoclass:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__unicode__
   :noindex:
